@@ -19,11 +19,11 @@ try:
 except ImportError:
     from ctrl import CTRLIN
 class HotKeyListener:
-    def __init__(self,catch=False):
+    def __init__(self,catch=False,blocking=True):
         self.hotkeys={}
         self.catch=catch
         self.__quit=False
-        self.blocking=True
+        self.blocking=blocking
         self.__thread=threading.Thread(target=self.__blocking,args=(lambda:self.__quit,))
     def __blocking(self,destroy):
         while not destroy():
